<Cfscript>
// Prerequisites:
// 1. You must create the VRAPI Stub Code using the wsdl2java program included with your Coldfusion installation. This can usually be found in the lib directory of your ColdFusion install directory. The call used to generate the stub code used in this example was:

// prompt> /Applications/ColdFusion9/runtime/bin/wsdl2java -a https://api.verticalresponse.com/partner-wsdl/1.0/VRAPI.wsdl

//You will also need to compile that stubcode. The commands we used were:

// prompt> javac -cp %CLASSPATH% -source 1.4 ./com/verticalresponse/api/_1_0/VRAPI/*.java
// prompt> javac -cp %CLASSPATH% -source 1.4 ./com/verticalresponse/api/_1_0/VRAPI_xsd/*.java

//The %CLASSPATH% variable *MUST* match the server classpath defined in your Coldfusion Adnisitration panel

// 2. If you are using the Partner WSDL, you must install the VerticalResponse certificate authority file in your trusted certificate store.


//-- Replace with your credentials
accountUsername = "Account Username";
accountPassword = "Account Password";

//<!-- CREATE THE SYSTEM OBJECT -->
sysObj = createObject("java", "java.lang.System");


//------ CERTIFICATE CODE ------//
// This is ONLY necessary if you're using the Partner WSDL and API.
//<!-- SET THE CERTIFICATE LOCATIONS -->
//This is the path to your master certificate file. Listed here is the default location for Mac OS X
//sysObj.setProperty ("javax.net.ssl.trustStore", "/System/Library/Frameworks/JavaVM.framework/Versions/1.6/Home/lib/security/cacerts");

//This is the default password for the master certs file
//sysObj.setProperty ("javax.net.ssl.trustStorePassword", "changeit");

//This should be the path to the P12 file we provided
//sysObj.setProperty ("javax.net.ssl.keyStore", "Certificate_path_here); 

//This should be the certificate passphrase
//sysObj.setProperty ("javax.net.ssl.keyStorePassword", "Certificate_passphrase_here"); 

//For the .p12 cert, don't change this
//sysObj.setProperty ("javax.net.ssl.keyStoreType", "PKCS12");

//------ END CERTIFICATE CODE ------//

//------ CREATE THE SOAP OBJECT ------//
// This calls the code generated by wsdl2java
vr = createObject("java", "com.verticalresponse.api._1_0.VRAPI.VRAPILocator").getVRAPIPort();


//------ LOGIN ------//
WriteOutput("<p><b>Logging into VR...</b></p>");


//You'll need to construct the args as direct Java objects.
loginArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.LoginArgs").Init();

//Your master account's VR email address/username
loginArgs.username=accountUsername;

//your master account's password
loginArgs.password=accountPassword; 

//To conform with the WSDL requirements, this must be a BigInteger
sessionTimeout = createObject("java", "java.math.BigInteger").Init("10");
loginArgs.session_duration_minutes=sessionTimeout;

//Partner API Only: Uncomment this and replace with a subaccount under your master account to access their data
//loginArgs.impersonate_user="subaccount@example.com"; 

session_id = vr.login(loginArgs);
WriteOutput("<p><b>Session Id: " & session_id & "</b></p>");

//------ CREATE LIST ------//
listArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.CreateListArgs").Init();
listArgs.session_id = session_id;
listArgs.name = "CF List - " & session_id;
listArgs.type = "email";
//Custom field names needs to be a Java array for this code.
cfnArray = ArrayNew(1);
cfnArray[1] = "NULL";
cfnArray2 = JavaCast("string[]", cfnArray);
listArgs.custom_field_names = cfnArray2;

listId = vr.createList(listArgs);
WriteOutput("<p><b>ListID:</b> " & listId &"</b></p>");

//------ ADD LIST MEMBER ------//
//I like to construct this going backward - member data first, add that to the ListMember, then add that to the ListMemberArgs
//Since we're doing this as a series of Java objects, it gets a shade messy.
nvPairClass = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.NVPair").GetClass();
arrayReflect = createObject("java", "java.lang.reflect.Array");
nvDictionary = arrayReflect.NewInstance(nvPairClass, JavaCast("int", 3));

nvPair = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.NVPair").Init();
nvPair.name = "email_address";
nvPair.value = "example@example.com";
arrayReflect.Set(nvDictionary, JavaCast("int", 0), nvPair);

nvPair = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.NVPair").Init();
nvPair.name = "first_name";
nvPair.value = "Sample";
arrayReflect.Set(nvDictionary, JavaCast("int", 1), nvPair);

nvPair = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.NVPair").Init();
nvPair.name = "last_name";
nvPair.value = "Recipient";
arrayReflect.Set(nvDictionary, JavaCast("int", 2), nvPair);

listMember = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.ListMember").Init();
listMember.member_data = nvDictionary;
listMember.list_id = listId;

listMemberArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.AddListMemberArgs").Init();
listMemberArgs.session_id = session_id;
listMemberArgs.list_member = listMember;

vr.addListMember(listMemberArgs);
WriteOutput("<p><b>Added List Member</b></p>");

//------ CREATE EMAIL EXAMPLE ------//

Email = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.Email").Init();
Email.name = "CF - " & session_id;
Email.email_type = "canvas";
Email.from_label = "Coldfusion Sample Code";
Email.freeform_html = "<h1>Coldfusion HTML Email Test</h1><p>This is the HTML generated by the sample code</p>";
Email.freeform_text = "Coldfusion Text Email. This was created using the Coldfusion Sample Code";
Email.tested = true;
Email.previewed_html = true;
Email.previewed_text = true;
Email.subject = "Test from CF";

Email.unsub_message = "In order to be removed form our list";
Email.unsub_link_text = "Click here to unsubscribe.";
Email.reply_to_email = accountUsername;
Email.postal_addr_1 = "501 2nd St. STE 700";
Email.postal_city = "San Francisco";
Email.postal_state = "California";
Email.postal_code = "94107";
Email.postal_country = "USA";


createEmailArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.CreateEmailArgs").Init();
createEmailArgs.session_id = session_id;
createEmailArgs.email = Email;

campaignId = vr.createEmail(createEmailArgs);
WriteOutput("<p><b>Campaign ID:</b> " & campaignId & "</p>");

//------ SET CAMPAIGN LISTS ------//

listArray = ArrayNew(1);
listArray[1] = listId;

setListArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.SetCampaignListsArgs").Init();
setListArgs.session_id = session_id;
setListArgs.campaign_id = campaignId;
setListArgs.list_ids = JavaCast("int[]", listArray);

vr.setCampaignLists(setListArgs);
WriteOutput("<p><b>Lists are set for the campaign</b></p>");


//------ Launch Email ------//
launchEmailArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.LaunchEmailCampaignArgs").Init();
launchEmailArgs.session_id = session_id;
launchEmailArgs.campaign_id = campaignId;

vr.launchEmailCampaign(launchEmailArgs);
WriteOutput("<p><b>Email Launched!</b></p>");

//------ SINGLE SIGN ON EXAMPLE ------//
//ONLY VALID WITH PARTNER API
//ssoArgs = createObject("java", "com.verticalresponse.api._1_0.VRAPI_xsd.GetUserSignonURLArgs").Init();
//ssoArgs.session_id = session_id;
//ssoArgs.user = "subaccount@domain.com";
//ssoArgs.ttl = 120;
//ssoArgs.logout_url = "http://www.verticalresponse.com"; //Replace with your logout URL

//ssoURL = vr.getUserSignonURL(ssoArgs);

//Usually, you would use this URL in an iFrame or a new window.
//WriteOutput("<p><b>Login URL: " & ssoURL & "</b></p>");

</cfscript>


<cffunction name= "CFDUMP" returntype="boolean" output="yes">
  <cfargument name="value" type="any" default="nothing to output">
  <CFDUMP var="#arguments.value#">
  <cfoutput><p></cfoutput>
  <cfreturn true>       
</cffunction>










